@@ -1,6 +1,6 @@
 ﻿/*
  * This file is part of danmaQ.
- * 
+ *
  * DanmaQ is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
@@ -17,35 +17,33 @@
 
 #ifndef DMCANVAS_HPP
 #define DMCANVAS_HPP
-#include <QWidget>
 #include <QVector>
+#include <QWidget>
 #include "DMMainWindow.hpp"
 #include "Danmaku.hpp"
 
-class DMCanvas: public QWidget
-{
-	Q_OBJECT
+class DMCanvas : public QWidget {
+  Q_OBJECT
 
-public:
-    DMCanvas(DMMainWindow *parent);
-    DMCanvas(int screenNumber, DMMainWindow *parent);
-	~DMCanvas();
-    DMMainWindow *mainWindow;
+ public:
+  DMCanvas(DMMainWindow* parent);
+  DMCanvas(QScreen* screen, DMMainWindow* parent);
+  ~DMCanvas();
+  DMMainWindow* mainWindow;
 
-	int slot_y(int slot);
+  int slot_y(int slot);
+  QRect screen;
+  QPoint getGlboalPoint(QPoint p);
 
+ public slots:
+  void new_danmaku(QString text, int color, int position);
+  void delete_danmaku(Danmaku*);
 
-public slots:
-	void new_danmaku(QString text, QString color, QString position);
-	void delete_danmaku(Danmaku*);
-	void clear_fly_slot(int slot);
-
-private:
-	QVector<bool> fly_slots, fixed_slots;
-	void init_slots();
-	int allocate_slot(Position);
-	QString escape_text(QString &);
-
+ private:
+  QVector<bool> fly_slots, fixed_slots;
+  void init_slots();
+  int allocate_slot(Position);
+  QString escape_text(QString&);
 };
 
 #endif
