@@ -1,6 +1,6 @@
 /*
  * This file is part of danmaQ.
- * 
+ *
  * DanmaQ is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
@@ -17,35 +17,36 @@
 
 #ifndef SUBSCRIBER_HPP
 #define SUBSCRIBER_HPP
+
 #include <QtCore>
-#include <QThread>
-#include <QNetworkAccessManager>
-#include <QNetworkRequest>
-#include <QTime>
+#include <QWebEngineView>
+#include <QtWebChannel>
 
+class Subscriber : public QObject {
+  Q_OBJECT
 
-class Subscriber : public QThread
-{
-	Q_OBJECT
-	
-public:
-	Subscriber(QString server, QString channel, QString passwd, QObject* parent=0);
-	void run();
-	bool mark_stop;
+ public:
+  Subscriber(QString server, QObject* parent = 0);
+  void start();
+  void finish();
 
-public slots:
-	void parse_response(QNetworkReply* reply);
+ public slots:
+  void show(QString text, int color, int position);
+  void connected();
+  void disconnected();
+  QString get_server();
+  void webError(QString text);
 
-signals:
-	void new_danmaku(QString text, QString color, QString position);
-	void new_alert(QString msg);
+ signals:
+  void new_danmaku(QString text, int color, int position);
+  void new_alert(QString msg);
+  void started();
+  void finished();
 
-private:
-	QNetworkAccessManager* http;
-	QNetworkRequest request;
-	QString server, channel, passwd, _uuid;
-	
+ private:
+  QWebEngineView* webView;
+  QWebChannel* webChannel;
+  QString server;
 };
 
-
-#endif 
+#endif
